@@ -77,7 +77,7 @@ pub fn print(
                 Col::Filesystem => csv.cell(&mount.info.fs),
                 Col::Label => csv.cell_opt(mount.fs_label.as_ref()),
                 Col::Type => csv.cell(&mount.info.fs_type),
-                Col::Remote => csv.cell(if mount.info.is_remote() { "yes" } else { "no" }),
+                Col::Remote => csv.cell(if mount.is_remote() { "yes" } else { "no" }),
                 Col::Disk => csv.cell_opt(mount.disk.as_ref().map(|d| d.disk_type())),
                 Col::Used => csv.cell_opt(mount.stats().map(|s| units.fmt(s.used()))),
                 Col::Use => csv.cell_opt(mount.stats().map(|s| s.use_share())),
@@ -105,6 +105,8 @@ pub fn print(
                 Col::MountPoint => csv.cell(mount.info.mount_point.to_string_lossy()),
                 Col::Uuid => csv.cell(mount.uuid.as_ref().map_or("", |v| v)),
                 Col::PartUuid => csv.cell(mount.part_uuid.as_ref().map_or("", |v| v)),
+                Col::MountOptions => csv.cell(mount.info.options_string()),
+                Col::CompressLevel => csv.cell_opt(mount.info.option_value("compress")),
             }?;
         }
         csv.end_line()?;
